using Microsoft.Extensions.Logging;
using Piwigo.Client.Albums;
using Piwigo.Client.Images;
using Piwigo.Client.Session;
using Piwigo.Client.Tags;

namespace Piwigo.Client;

public class PiwigoClient : IPiwigoClient
{
    public PiwigoClient(IImageApi image, ITagApi tag, ISessionApi session, IAlbumApi album)
    {
        Image = image ?? throw new ArgumentNullException(nameof(image));
        Tag = tag ?? throw new ArgumentNullException(nameof(tag));
        Session = session ?? throw new ArgumentNullException(nameof(session));
        Album = album ?? throw new ArgumentNullException(nameof(album));
    }

    public IImageApi Image { get; }
    public ITagApi Tag { get; }
    public ISessionApi Session { get; }
    public IAlbumApi Album { get; }

    public static IPiwigoClient CreateClient(string baseUri, string userName, string password, ILoggerFactory loggerFactory)
    {
        var configuration = new PiwigoConfiguration(baseUri, userName, password);
        var context = new PiwigoContext(configuration, loggerFactory.CreateLogger<PiwigoContext>());

        IImageApi imageApi = new ImageApi(context, loggerFactory.CreateLogger<ImageApi>());
        var tagApi = new TagApi(context, loggerFactory.CreateLogger<TagApi>());
        var sessionApi = new SessionApi(context, loggerFactory.CreateLogger<SessionApi>());
        var albumApi = new AlbumApi(context, loggerFactory.CreateLogger<AlbumApi>());
        var piwigoClient = new PiwigoClient(imageApi, tagApi, sessionApi, albumApi);
        return piwigoClient;
    }
}